@@ -11,7 +11,7 @@ my $dev = 0;
 $dev    = $ARGV[0] if (scalar(@ARGV));
 print "Using /dev/fb$dev\n";
 sleep 1;
-if (open(my $FILE,'<','dump.log')) {
+if (open(my $FILE,'>','dump.log')) {
     eval {
         my $fb = Graphics::Framebuffer->new('SHOW_ERRORS' => 1, 'FB_DEVICE' => "/dev/fb$dev");
         $fb->cls();
