@@ -103,7 +103,7 @@ if ($DB) {                                # If double buffering is on, then enab
 print_it($F, ' ', '00FFFFFF');
 $F->splash($VERSION);
 my $LOGO = $F->blit_read();    # Get a memory copy of the splash screen
-
+my $DORKSMILE;
 foreach my $file (@files) {
     next if ($file =~ /^\.+/ || $file =~ /Test|gif/ || -d "$images_path/$file");
     print_it($F, "Loading Images > $file", '00FFFFFF', undef, 1);
@@ -114,24 +114,29 @@ foreach my $file (@files) {
             'width'        => $XX,
             'height'       => $F->{'H_CLIP'},
             'file'         => "$images_path/$file",
-            'convertalpha' => ($file =~ /wolf|Crescent/i) ? 1 : 0,
+            'convertalpha' => ($file =~ /wolf|Crescent|dork/i) ? 1 : 0,
             'center'       => CENTER_XY,
         }
     );
-    push(@IMAGES, $image) if (defined($image));
-    $image = $F->load_image(
-        {
-            'x'            => 0,
-            'y'            => 0,
-            'width'        => $XX * .5,
-            'height'       => $F->{'H_CLIP'} * .5,
-            'file'         => "$images_path/$file",
-            'convertalpha' => ($file =~ /wolf|Crescent/i) ? 1 : 0,
-            'center'       => CENTER_XY,
-        }
-    );
-    push(@SMALL_IMAGES, $image) if (defined($image));
-    $BW = scalar(@IMAGES) - 1 if ($file =~ /wolf/i);
+    unless ($file =~ /dorksmile/i) {
+        push(@IMAGES, $image) if (defined($image));
+        $image = $F->load_image(
+            {
+                'x'            => 0,
+                'y'            => 0,
+                'width'        => $XX * .5,
+                'height'       => $F->{'H_CLIP'} * .5,
+                'file'         => "$images_path/$file",
+                'convertalpha' => ($file =~ /wolf|Crescent|dork/i) ? 1 : 0,
+                'center'       => CENTER_XY,
+            }
+        );
+        push(@SMALL_IMAGES, $image) if (defined($image));
+        $BW = scalar(@IMAGES) - 1 if ($file =~ /wolf/i);
+    } else {
+        $DORKSMILE = $image;
+    }
+
 } ## end foreach my $file (@files)
 
 $F->wait_for_console(!$rpi);
@@ -192,13 +197,14 @@ truetype_fonts();
 
 # rotate_truetype_fonts();
 
-color_replace_with_clipping();
-color_replace_no_clipping();
+foreach my $flag (0..1) {
+    color_replace($flag);
+}
 
 blitting();
 blit_move();
 rotate();
-flipping();
+# flipping();
 monochrome();
 foreach my $m (1 .. 9) {    # We skip divide mode because it's stupid and I should never have added it
     if ($m == MASK_MODE) {
@@ -1134,17 +1140,22 @@ sub flood_fill {
     sleep $factor if ($F->{'ACCELERATED'});
 } ## end sub flood_fill
 
-sub color_replace_with_clipping {
-
-    print_it($F, 'Testing Color Replace (clipping on)');
+sub color_replace {
+    my $clipped = shift;
+    if ($clipped) {
+        print_it($F, 'Testing Color Replace (clipping on)');
+    } else {
+        print_it($F, 'Testing Color Replace (clipping off)');
+    }
 
     my $x = $F->{'XRES'} / 4;
     my $y = $F->{'YRES'} / 4;
-    $F->blit_write($LOGO);
-    $F->clip_set({ 'x' => $x, 'y' => $y, 'xx' => $x * 3, 'yy' => $y * 3 });
-    my $r = 128;
-    my $g = 0;
-    my $b = 0;
+
+    $F->blit_write($DORKSMILE);
+    $F->clip_set({ 'x' => $x * 1.5, 'y' => $y, 'xx' => $x * 3, 'yy' => $y * 3 }) if ($clipped);
+    my $r = 255;
+    my $g = 223;
+    my $b = 88;
     my $s = time + $factor;
     while (time < $s) {
         my $R = int(rand(256));
@@ -1170,42 +1181,6 @@ sub color_replace_with_clipping {
     } ## end while (time < $s)
 } ## end sub color_replace_with_clipping
 
-sub color_replace_no_clipping {
-
-    print_it($F, 'Testing Color Replace (clipping off)');
-
-    $F->blit_write($LOGO);
-
-    $F->clip_reset();
-
-    my $r = 128;
-    my $g = 0;
-    my $b = 0;
-    my $s = time + $factor;
-    while (time < $s) {
-        my $R = int(rand(256));
-        my $G = int(rand(256));
-        my $B = int(rand(256));
-        $F->replace_color(
-            {
-                'old' => {
-                    'red'   => $r,
-                    'green' => $g,
-                    'blue'  => $b
-                },
-                'new' => {
-                    'red'   => $R,
-                    'green' => $G,
-                    'blue'  => $B
-                }
-            }
-        );
-        ($r, $g, $b) = ($R, $G, $B);
-        $DIRTY = 1;
-
-    } ## end while (time < $s)
-} ## end sub color_replace_no_clipping
-
 sub blitting {
 
     print_it($F, 'Testing Image blitting');
@@ -1260,7 +1235,7 @@ sub rotate {
             $st .= 'Using High Quality Setting';
         }
         print_it($F, $st);
-        my $s = time + ($factor * 2);
+        my $s = time + $factor;
         my $count = 0;
 
         while (time < $s || $count < 6) {
@@ -1296,7 +1271,7 @@ sub rotate {
             $st .= 'Using High Quality Setting';
         }
         print_it($F, $st);
-        $s = time + ($factor * 2);
+        $s = time + $factor;
         $count = 0;
         while (time < $s || $count < 6) {
             my $rot = $F->blit_transform(
@@ -1424,9 +1399,8 @@ sub animated {
                     $F->cls();
                     my $fps   = 0;
                     my $start = time;
-                    my $s     = time + ($factor * 2);
+                    my $s     = time + $factor;
 
-                    #                    $F->mask_mode() if ($F->{'ACCELERATED'} && ! $F->{'FILE_MODE'});
                     while (time <= $s) {
                         foreach my $frame (0 .. (scalar(@{$image}) - 1)) {
                             if (time > $s * 2) {
