@@ -15,9 +15,15 @@ use Time::HiRes qw(sleep time);
 use List::Util qw(shuffle);
 
 # use Data::Dumper::Simple;
-my @a    = @ARGV;
-my $path = pop(@a);
-my $args = join('', @a);
+my (@a,$path,$args);
+if (scalar(@ARGV)) {
+    @a    = @ARGV;
+    $path = pop(@a);
+    $args = join('', @a);
+} else {
+    $path = (-d "images/") ? 'images/' : 'examples/images/';
+    $args = 'full';
+}
 
 my $errors = 0;
 $errors = 1 if ($args =~ /errors/i);
